<?php

namespace Drupal\terms_export_import\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\terms_export_import\Service\TermsExportImportService;
use Symfony\Component\HttpFoundation\Response;

class TermExportForm extends FormBase {

    /**
     * @var \Drupal\terms_export_import\Service\TermsExportImportService
     */
    protected $exportImportService;

    public static function create(ContainerInterface $container) {
        $instance = parent::create($container);
        $instance->exportImportService = $container->get('terms_export_import.service');
        return $instance;
    }

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'terms_export_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        $form['vocabulary'] = [
            '#type' => 'entity_autocomplete',
            '#title' => $this->t('Vocabulary'),
            '#target_type' => 'taxonomy_vocabulary',
            '#required' => TRUE,
            '#description' => $this->t('Select the vocabulary to export.'),
        ];

        $form['actions'] = [
            '#type' => 'actions',
        ];

        $form['actions']['submit'] = [
            '#type' => 'submit',
            '#value' => $this->t('Export CSV'),
        ];

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        $vocabulary_id = $form_state->getValue('vocabulary');
        // Retrieve vocabulary machine name from the entity_autocomplete.
        // The autocomplete returns a label and entity ID. We need the machine name of the vocabulary.
        $vocab = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary')->load($vocabulary_id);
        if (!$vocab) {
            $this->messenger()->addError($this->t('Invalid vocabulary selected.'));
            return;
        }

        $terms_data = $this->exportImportService->exportTerms($vocab->id());
        $csv = $this->exportImportService->convertToCsv($terms_data);

        // Return as CSV file download.
        $response = new Response($csv);
        $response->headers->set('Content-Type', 'text/csv; charset=UTF-8');
        $filename = $vocab->id() . '-terms-export.csv';
        $response->headers->set('Content-Disposition', 'attachment; filename="'.$filename.'"');
        $form_state->setResponse($response);
    }
}